@@ -19,7 +19,7 @@ var fs=require('fs');
 var session = require('express-session');
 var RDBStore = require('./rethinkdb-session')(session);
 var passport = require('passport');
-const route_dir="/app/routes";
+var logger = require('winston');
 //const global_dir="/app/global";
 
 
@@ -27,7 +27,7 @@ module.exports=function(db,config,validator,jvm,manifest){
     var app = express();
     //console.log(validate_model);
 
-    console.log("nylon Server run at env : "+process.env.NODE_ENV);
+   logger.info("nylon Server run at env : "+process.env.NODE_ENV);
 
     var rdbStore = new RDBStore({
             connection: db,
@@ -73,56 +73,19 @@ module.exports=function(db,config,validator,jvm,manifest){
     }*/
 
     app.use(function(req,res,next){
-         //console.log("client request pid "+process.pid +" app name " + app_name);
+        logger.info("client req "+req.url);
+
          req._r=db;
          req._config=config;
          req._validator=validator;
          req._jvm=jvm;
-
-         var urls = req.url.split("/");
-         console.log(req.url);
-         if(urls.length>=2){
-            if(urls[1]=="api"){
-                var re_url=work_dir+route_dir+"/"+urls[2]+".routes.js";
-                var nurl="";
-                for(var i=3;i<urls.length;i++){
-                        nurl=nurl+"/"+urls[i];
-                }
-                if(urls.length==3){
-                    nurl=nurl+"/";
-                }
-                console.log(nurl);
-                require(re_url)(app);
-                req.url=nurl;
-            }
-         }
-
-            
          next();
+
     });
 
-
-
-    require('./iReport')(app);
-    require('./oauth/oauth.routes')(app);
-
-
-
     app.set('views',work_dir+'/app/views');
     app.set('view engine','jade');
 
-    //config routes
-    /*var routes = fs.readdirSync(work_dir+route_dir);
-    for (var i in routes){
-        if(routes[i].endsWith(".routes.js")){
-            var r = route_dir + '/' + routes[i];
-            //console.log(r);
-            require(work_dir+r)(app);
-            console.log("nylon start route :: "+r);
-        }
-    }*/
-
-    
 
     app.use(sass({
         src:work_dir+'/sass',
@@ -141,4 +104,4 @@ module.exports=function(db,config,validator,jvm,manifest){
      // next();
   //  });
     return app;
-}
\ No newline at end of file
+}
