@@ -16,6 +16,7 @@ const watcher=require('./watcher');
 const validator=require('./validator');
 const rethinkdb=require('./rethinkdb');
 const express =require('./express');
+const express_route =require('./express-load-route');
 const http=require('http');
 const passport =require('./passport');
 const java = require('./java');
@@ -23,6 +24,18 @@ const iReport = require('./iReport');
 const socket = require('./socket');
 const http2 =require('spdy');
 const fs =require('fs');
+var logger = require('winston');
+const work_dir=process.cwd();
+
+var now = new Date();
+var logger_f="L"+now.getFullYear() + now.getMonth()+ now.getDate();
+
+logger.configure({
+    transports: [
+      new (logger.transports.Console)(),
+      new (logger.transports.File)({ filename: work_dir+'/loggers/'+logger_f+".log" })
+    ]
+});
 
 
 
@@ -35,7 +48,7 @@ exports.serve= function(path){
 
         cluster.on('exit', (worker, code, signal) => {
             cluster.fork();
-            console.log('worker '+worker.process.pid+' died');
+            logger.info('worker '+worker.process.pid+' died');
         });
 
        watcher.addWatcher(process.cwd()+'/app');
@@ -50,6 +63,11 @@ exports.serve= function(path){
 
         var db  = rethinkdb(config);
         var app = express(db,config,validator.ajv,java.jvm,manifest);
+
+        require('./express-load-route')(app);
+        require('./iReport')(app);
+        require('./oauth/oauth.routes')(app);
+
         var server =http.createServer(app); 
 
         var options = {
@@ -69,15 +87,18 @@ exports.serve= function(path){
         var oauth=passport(db,config);
         
         server.listen(config.server.port, function (error) {
-            console.error(error);
-            console.log('Nylon server listening on port ' + config.server.port + ' pid '+process.pid);
+            if(error){
+                logger.error( error);
+            }else{
+                logger.info('Nylon server listening on port ' + config.server.port + ' pid '+process.pid);
+            }
 
             
         });
 
 
         process.on('uncaughtException', function(err){
-            console.log(err);
+            logger.error( err);
             process.exit(1);
         });
 
